allRulesEnabled property
When true, isDisabledInProject always returns false.
Only for use in the test harness entry point. Must not be set in production code or from individual tests.
Implementation
static bool allRulesEnabled = false;
When true, isDisabledInProject always returns false.
Only for use in the test harness entry point. Must not be set in production code or from individual tests.
static bool allRulesEnabled = false;