IgnoreInfo class

Parses // ignore: and // ignore_for_file: comments from Dart source.

Properties

fileIgnores Set<String>
final
hashCode int
The hash code for this object.
no setterinherited
lineIgnores Map<int, Set<String>>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

isIgnored(String ruleName, int lineNumber) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

parse(String content) IgnoreInfo