allRulesEnabled property

bool allRulesEnabled
getter/setter pair

When true, isDisabledInProject always returns false.

Only for use in the test harness entry point. Must not be set in production code or from individual tests.

Implementation

static bool allRulesEnabled = false;